@@ -1,17 +1,22 @@
-/* lib/des/cfb64enc.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/des/cfb64enc.c */
+/* Copyright (C) 1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -52,7 +63,7 @@
  * 64bit block we have used is contained in *num;
  */
 
-int des_cfb64_encrypt(in, out, length, schedule, ivec, num, encrypt)
+void des_cfb64_encrypt(in, out, length, schedule, ivec, num, encrypt)
 unsigned char *in;
 unsigned char *out;
 long length;
@@ -61,9 +72,10 @@ des_cblock (*ivec);
 int *num;
 int encrypt;
 	{
-	register unsigned long v0,v1;
-	register long l=length,n=*num;
-	unsigned long ti[2];
+	register DES_LONG v0,v1;
+	register long l=length;
+	register int n= *num;
+	DES_LONG ti[2];
 	unsigned char *iv,c,cc;
 
 	iv=(unsigned char *)ivec;
@@ -73,16 +85,13 @@ int encrypt;
 			{
 			if (n == 0)
 				{
-				c2l(iv,v0);
-				c2l(iv,v1);
-				ti[0]=v0;
-				ti[1]=v1;
-				des_encrypt((unsigned long *)ti,
-					(unsigned long *)ti,
+				c2l(iv,v0); ti[0]=v0;
+				c2l(iv,v1); ti[1]=v1;
+				des_encrypt((DES_LONG *)ti,
 					schedule,DES_ENCRYPT);
 				iv=(unsigned char *)ivec;
-				l2c(ti[0],iv);
-				l2c(ti[1],iv);
+				v0=ti[0]; l2c(v0,iv);
+				v0=ti[1]; l2c(v0,iv);
 				iv=(unsigned char *)ivec;
 				}
 			c= *(in++)^iv[n];
@@ -97,16 +106,13 @@ int encrypt;
 			{
 			if (n == 0)
 				{
-				c2l(iv,v0);
-				c2l(iv,v1);
-				ti[0]=v0;
-				ti[1]=v1;
-				des_encrypt((unsigned long *)ti,
-					(unsigned long *)ti,
+				c2l(iv,v0); ti[0]=v0;
+				c2l(iv,v1); ti[1]=v1;
+				des_encrypt((DES_LONG *)ti,
 					schedule,DES_ENCRYPT);
 				iv=(unsigned char *)ivec;
-				l2c(ti[0],iv);
-				l2c(ti[1],iv);
+				v0=ti[0]; l2c(v0,iv);
+				v0=ti[1]; l2c(v0,iv);
 				iv=(unsigned char *)ivec;
 				}
 			cc= *(in++);
@@ -118,6 +124,5 @@ int encrypt;
 		}
 	v0=v1=ti[0]=ti[1]=c=cc=0;
 	*num=n;
-	return(0);
 	}
 
