@@ -1,17 +1,22 @@
-/* lib/des/des.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/des/des.c */
+/* Copyright (C) 1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -55,7 +66,7 @@
 #endif
 
 #include <time.h>
-#include "version.h"
+#include "des_ver.h"
 
 #ifdef VMS
 #include <types.h>
@@ -80,7 +91,7 @@
 #define srandom(s) srand(s)
 #endif
 
-#ifdef PROTO
+#ifndef NOPROTO
 void usage(void);
 void doencryption(void);
 int uufwrite(unsigned char *data, int size, unsigned int num, FILE *fp);
@@ -113,7 +124,7 @@ int do_encrypt,longk=0;
 FILE *DES_IN,*DES_OUT,*CKSUM_OUT;
 char uuname[200];
 unsigned char uubuf[50];
-int uubufnum;
+int uubufnum=0;
 #define INUUBUFN	(45*100)
 #define OUTUUBUF	(65*100)
 unsigned char b[OUTUUBUF];
@@ -247,7 +258,7 @@ char **argv;
 		if (vflag) 
 			{
 #ifndef _Windows			
-			fprintf(stderr,"des(1) built with %s\n",DES_version);
+			fprintf(stderr,"des(1) built with %s\n",libdes_version);
 #endif			
 			EXIT(1);
 			}
@@ -255,7 +266,7 @@ char **argv;
 		}
 
 #ifndef _Windows			
-	if (vflag) fprintf(stderr,"des(1) built with %s\n",DES_version);
+	if (vflag) fprintf(stderr,"des(1) built with %s\n",libdes_version);
 #endif			
 	if (	(in != NULL) &&
 		(out != NULL) &&
@@ -377,8 +388,8 @@ void doencryption()
 
 	if (buf == NULL)
 		{
-		if (    (( buf=(unsigned char *)malloc(BUFSIZE+8)) == NULL) ||
-			((obuf=(unsigned char *)malloc(BUFSIZE+8)) == NULL))
+		if (    (( buf=(unsigned char *)Malloc(BUFSIZE+8)) == NULL) ||
+			((obuf=(unsigned char *)Malloc(BUFSIZE+8)) == NULL))
 			{
 			fputs("Not enough memory\n",stderr);
 			Exit=10;
@@ -512,7 +523,7 @@ void doencryption()
 						ks,do_encrypt);
 			else if (flag3 && bflag)
 				for (i=0; i<l; i+=8)
-					des_2ecb_encrypt(
+					des_ecb2_encrypt(
 						(des_cblock *)&(buf[i]),
 						(des_cblock *)&(obuf[i]),
 						ks,ks2,do_encrypt);
@@ -591,7 +602,7 @@ void doencryption()
 						ks,do_encrypt);
 			else if (flag3 && bflag)
 				for (i=0; i<l; i+=8)
-					des_2ecb_encrypt(
+					des_ecb2_encrypt(
 						(des_cblock *)&(buf[i]),
 						(des_cblock *)&(obuf[i]),
 						ks,ks2,do_encrypt);
@@ -625,8 +636,7 @@ void doencryption()
 					{
 					fputs("The file was not decrypted correctly.\n",
 						stderr);
-					/*Exit=8;
-					goto problems;*/
+					Exit=8;
 					last=0;
 					}
 				l=l-8+last;
@@ -722,7 +732,7 @@ FILE *fp;
 			}
 		}
 
-	for (i=0; i<(num-INUUBUFN); i+=INUUBUFN)
+	for (i=0; i<(((int)num)-INUUBUFN); i+=INUUBUFN)
 		{
 		j=uuencode(&(data[i]),INUUBUFN,b);
 		fwrite(b,1,(unsigned int)j,fp);
@@ -827,9 +837,9 @@ FILE *fp;
 	return(tot);
 	}
 
-#define ccc2l(c,l)      (l =((unsigned long)(*((c)++)))<<16, \
-			 l|=((unsigned long)(*((c)++)))<< 8, \
-		 	 l|=((unsigned long)(*((c)++))))
+#define ccc2l(c,l)      (l =((DES_LONG)(*((c)++)))<<16, \
+			 l|=((DES_LONG)(*((c)++)))<< 8, \
+		 	 l|=((DES_LONG)(*((c)++))))
 
 #define l2ccc(l,c)      (*((c)++)=(unsigned char)(((l)>>16)&0xff), \
                     *((c)++)=(unsigned char)(((l)>> 8)&0xff), \
@@ -842,7 +852,7 @@ int num;
 unsigned char *out;
 	{
 	int j,i,n,tot=0;
-	unsigned long l;
+	DES_LONG l;
 	register unsigned char *p;
 	p=out;
 
@@ -876,8 +886,8 @@ unsigned char *out;
 	{
 	int j,i,k;
 	unsigned int n=0,space=0;
-	unsigned long l;
-	unsigned long w,x,y,z;
+	DES_LONG l;
+	DES_LONG w,x,y,z;
 	unsigned int blank=(unsigned int)'\n'-' ';
 
 	for (j=0; j<num; )
