@@ -1,17 +1,22 @@
-/* lib/des/destest.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/des/destest.c */
+/* Copyright (C) 1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -45,6 +56,12 @@
  * [including the GNU Public Licence.]
  */
 
+#if defined(WIN32) || defined(WIN16) || defined(WINDOWS)
+#ifndef MSDOS
+#define MSDOS
+#endif
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #ifndef MSDOS
@@ -166,7 +183,7 @@ static unsigned char cipher_data[NUM_TESTS][8]={
 	{0xD5,0xD4,0x4F,0xF7,0x20,0x68,0x3D,0x0D},
 	{0x2A,0x2B,0xB0,0x08,0xDF,0x97,0xC2,0xF2}};
 
-static unsigned char cipher_2ecb[NUM_TESTS-1][8]={
+static unsigned char cipher_ecb2[NUM_TESTS-1][8]={
 	{0x92,0x95,0xB5,0x9B,0xB3,0x84,0x73,0x6E},
 	{0x19,0x9E,0x9D,0x6D,0xF3,0x9A,0xA8,0x16},
 	{0x2A,0x4B,0x4D,0x24,0x52,0x43,0x84,0x27},
@@ -213,6 +230,13 @@ static unsigned char cbc_ok[32]={
 	0x46,0x8e,0x91,0x15,0x78,0x88,0xba,0x68,
 	0x1d,0x26,0x93,0x97,0xf7,0xfe,0x62,0xb4};
 
+static unsigned char xcbc_ok[32]={
+	0x86,0x74,0x81,0x0D,0x61,0xA4,0xA5,0x48,
+	0xB9,0x93,0x03,0xE1,0xB8,0xBB,0xBD,0xBD,
+	0x64,0x30,0x0B,0xB9,0x06,0x65,0x81,0x76,
+	0x04,0x1D,0x77,0x62,0x17,0xCA,0x2B,0xD2,
+	};
+
 static unsigned char cbc3_ok[32]={
 	0x3F,0xE3,0x01,0xC9,0x62,0xAC,0x01,0xD0,
 	0x22,0x13,0x76,0x3C,0x1C,0xBD,0x4C,0xDC,
@@ -261,17 +285,19 @@ static unsigned char ofb_cipher[24]=
 	0x3d,0x6d,0x5b,0xe3,0x25,0x5a,0xf8,0xc3
 	};
 
-unsigned long cbc_cksum_ret=0xB462FEF7L;
+DES_LONG cbc_cksum_ret=0xB462FEF7L;
 unsigned char cbc_cksum_data[8]={0x1D,0x26,0x93,0x97,0xf7,0xfe,0x62,0xb4};
 
-#ifdef PROTO
+#ifndef NOPROTO
 static char *pt(unsigned char *p);
 static int cfb_test(int bits, unsigned char *cfb_cipher);
 static int cfb64_test(unsigned char *cfb_cipher);
+static int ede_cfb64_test(unsigned char *cfb_cipher);
 #else
 static char *pt();
 static int cfb_test();
 static int cfb64_test();
+static int ede_cfb64_test();
 #endif
 
 int main(argc,argv)
@@ -283,16 +309,16 @@ char *argv[];
 	des_key_schedule ks,ks2,ks3;
 	unsigned char cbc_in[40];
 	unsigned char cbc_out[40];
-	unsigned long cs;
+	DES_LONG cs;
 	unsigned char qret[4][4],cret[8];
-	unsigned long lqret[4];
+	DES_LONG lqret[4];
 	int num;
 	char *str;
 
 	printf("Doing ecb\n");
 	for (i=0; i<NUM_TESTS; i++)
 		{
-		if ((j=key_sched((C_Block *)(key_data[i]),ks)) != 0)
+		if ((j=des_key_sched((C_Block *)(key_data[i]),ks)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+1,j);
 			err=1;
@@ -321,17 +347,17 @@ char *argv[];
 	printf("Doing ede ecb\n");
 	for (i=0; i<(NUM_TESTS-1); i++)
 		{
-		if ((j=key_sched((C_Block *)(key_data[i]),ks)) != 0)
+		if ((j=des_key_sched((C_Block *)(key_data[i]),ks)) != 0)
 			{
 			err=1;
 			printf("Key error %2d:%d\n",i+1,j);
 			}
-		if ((j=key_sched((C_Block *)(key_data[i+1]),ks2)) != 0)
+		if ((j=des_key_sched((C_Block *)(key_data[i+1]),ks2)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+2,j);
 			err=1;
 			}
-		if ((j=key_sched((C_Block *)(key_data[i+2]),ks3)) != 0)
+		if ((j=des_key_sched((C_Block *)(key_data[i+2]),ks3)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+3,j);
 			err=1;
@@ -339,15 +365,15 @@ char *argv[];
 		memcpy(in,plain_data[i],8);
 		memset(out,0,8);
 		memset(outin,0,8);
-		des_2ecb_encrypt((C_Block *)in,(C_Block *)out,ks,ks2,
+		des_ecb2_encrypt((C_Block *)in,(C_Block *)out,ks,ks2,
 			DES_ENCRYPT);
-		des_2ecb_encrypt((C_Block *)out,(C_Block *)outin,ks,ks2,
+		des_ecb2_encrypt((C_Block *)out,(C_Block *)outin,ks,ks2,
 			DES_DECRYPT);
 
-		if (memcmp(out,cipher_2ecb[i],8) != 0)
+		if (memcmp(out,cipher_ecb2[i],8) != 0)
 			{
 			printf("Encryption error %2d\nk=%s p=%s o=%s act=%s\n",
-				i+1,pt(key_data[i]),pt(in),pt(cipher_2ecb[i]),
+				i+1,pt(key_data[i]),pt(in),pt(cipher_ecb2[i]),
 				pt(out));
 			err=1;
 			}
@@ -360,7 +386,7 @@ char *argv[];
 		}
 
 	printf("Doing cbc\n");
-	if ((j=key_sched((C_Block *)cbc_key,ks)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
@@ -381,18 +407,46 @@ char *argv[];
 		err=1;
 		}
 
+	printf("Doing desx cbc\n");
+	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
+		{
+		printf("Key error %d\n",j);
+		err=1;
+		}
+	memset(cbc_out,0,40);
+	memset(cbc_in,0,40);
+	memcpy(iv3,cbc_iv,sizeof(cbc_iv));
+	des_xcbc_encrypt((C_Block *)cbc_data,(C_Block *)cbc_out,
+		(long)strlen((char *)cbc_data)+1,ks,
+		(C_Block *)iv3,
+		(C_Block *)cbc2_key, (C_Block *)cbc3_key, DES_ENCRYPT);
+	if (memcmp(cbc_out,xcbc_ok,32) != 0)
+		{
+		printf("des_xcbc_encrypt encrypt error\n");
+		}
+	memcpy(iv3,cbc_iv,sizeof(cbc_iv));
+	des_xcbc_encrypt((C_Block *)cbc_out,(C_Block *)cbc_in,
+		(long)strlen((char *)cbc_data)+1,ks,
+		(C_Block *)iv3,
+		(C_Block *)cbc2_key, (C_Block *)cbc3_key, DES_DECRYPT);
+	if (memcmp(cbc_in,cbc_data,32) != 0)
+		{
+		printf("des_xcbc_encrypt decrypt error\n");
+		err=1;
+		}
+
 	printf("Doing ede cbc\n");
-	if ((j=key_sched((C_Block *)cbc_key,ks)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	if ((j=key_sched((C_Block *)cbc2_key,ks2)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc2_key,ks2)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	if ((j=key_sched((C_Block *)cbc3_key,ks3)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc3_key,ks3)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
@@ -425,7 +479,7 @@ char *argv[];
 		}
 
 	printf("Doing pcbc\n");
-	if ((j=key_sched((C_Block *)cbc_key,ks)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
@@ -459,7 +513,7 @@ char *argv[];
 	printf("cfb64 ");
 	err+=cfb_test(64,cfb_cipher64);
 
-	printf("cfb64 ");
+	printf("cfb64() ");
 	err+=cfb64_test(cfb_cipher64);
 
 	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
@@ -481,10 +535,14 @@ char *argv[];
 		printf("cfb_encrypt small decrypt error\n");
 		err=1;
 		}
+
+	printf("ede_cfb64() ");
+	err+=ede_cfb64_test(cfb_cipher64);
+
 	printf("done\n");
 
 	printf("Doing ofb\n");
-	key_sched((C_Block *)ofb_key,ks);
+	des_key_sched((C_Block *)ofb_key,ks);
 	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
 	des_ofb_encrypt(plain,ofb_buf1,64,(long)sizeof(plain)/8,ks,
 		(C_Block *)ofb_tmp);
@@ -503,7 +561,7 @@ char *argv[];
 		}
 
 	printf("Doing ofb64\n");
-	key_sched((C_Block *)ofb_key,ks);
+	des_key_sched((C_Block *)ofb_key,ks);
 	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
 	memset(ofb_buf1,0,sizeof(ofb_buf1));
 	memset(ofb_buf2,0,sizeof(ofb_buf1));
@@ -528,14 +586,40 @@ char *argv[];
 		err=1;
 		}
 
+	printf("Doing ede_ofb64\n");
+	des_key_sched((C_Block *)ofb_key,ks);
+	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
+	memset(ofb_buf1,0,sizeof(ofb_buf1));
+	memset(ofb_buf2,0,sizeof(ofb_buf1));
+	num=0;
+	for (i=0; i<sizeof(plain); i++)
+		{
+		des_ede3_ofb64_encrypt(&(plain[i]),&(ofb_buf1[i]),1,ks,ks,ks,
+			(C_Block *)ofb_tmp,&num);
+		}
+	if (memcmp(ofb_cipher,ofb_buf1,sizeof(ofb_buf1)) != 0)
+		{
+		printf("ede_ofb64_encrypt encrypt error\n");
+		err=1;
+		}
+	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
+	num=0;
+	des_ede3_ofb64_encrypt(ofb_buf1,ofb_buf2,(long)sizeof(ofb_buf1),ks,
+		ks,ks,(C_Block *)ofb_tmp,&num);
+	if (memcmp(plain,ofb_buf2,sizeof(ofb_buf2)) != 0)
+		{
+		printf("ede_ofb64_encrypt decrypt error\n");
+		err=1;
+		}
+
 	printf("Doing cbc_cksum\n");
-	key_sched((C_Block *)cbc_key,ks);
-	cs=cbc_cksum((C_Block *)cbc_data,(C_Block *)cret,
+	des_key_sched((C_Block *)cbc_key,ks);
+	cs=des_cbc_cksum((C_Block *)cbc_data,(C_Block *)cret,
 		(long)strlen(cbc_data),ks,(C_Block *)cbc_iv);
 	if (cs != cbc_cksum_ret)
 		{
 		printf("bad return value (%08lX), should be %08lX\n",
-			cs,cbc_cksum_ret);
+			(unsigned long)cs,(unsigned long)cbc_cksum_ret);
 		err=1;
 		}
 	if (memcmp(cret,cbc_cksum_data,8) != 0)
@@ -553,9 +637,9 @@ char *argv[];
 		memcpy(&(lqret[i]),&(qret[i][0]),4);
 		}
 	{ /* Big-endian fix */
-	static unsigned long l=1;
+	static DES_LONG l=1;
 	static unsigned char *c=(unsigned char *)&l;
-	unsigned long ll;
+	DES_LONG ll;
 
 	if (!c[0])
 		{
@@ -569,31 +653,32 @@ char *argv[];
 	}
 	if (cs != 0x70d7a63aL)
 		{
-		printf("quad_cksum error, ret %08lx should be 70d7a63a\n",cs);
+		printf("quad_cksum error, ret %08lx should be 70d7a63a\n",
+			(unsigned long)cs);
 		err=1;
 		}
 	if (lqret[0] != 0x327eba8dL)
 		{
 		printf("quad_cksum error, out[0] %08lx is not %08lx\n",
-			lqret[0],0x327eba8dL);
+			(unsigned long)lqret[0],0x327eba8dL);
 		err=1;
 		}
 	if (lqret[1] != 0x201a49ccL)
 		{
 		printf("quad_cksum error, out[1] %08lx is not %08lx\n",
-			lqret[1],0x201a49ccL);
+			(unsigned long)lqret[1],0x201a49ccL);
 		err=1;
 		}
 	if (lqret[2] != 0x70d7a63aL)
 		{
 		printf("quad_cksum error, out[2] %08lx is not %08lx\n",
-			lqret[2],0x70d7a63aL);
+			(unsigned long)lqret[2],0x70d7a63aL);
 		err=1;
 		}
 	if (lqret[3] != 0x501c2c26L)
 		{
 		printf("quad_cksum error, out[3] %08lx is not %08lx\n",
-			lqret[3],0x501c2c26L);
+			(unsigned long)lqret[3],0x501c2c26L);
 		err=1;
 		}
 
@@ -629,9 +714,7 @@ char *argv[];
 		}
 	printf("\n");
 	exit(err);
-#ifdef LINT
 	return(0);
-#endif
 	}
 
 static char *pt(p)
@@ -653,7 +736,7 @@ unsigned char *p;
 	ret[16]='\0';
 	return(ret);
 	}
-	
+
 static int cfb_test(bits, cfb_cipher)
 int bits;
 unsigned char *cfb_cipher;
@@ -661,7 +744,7 @@ unsigned char *cfb_cipher;
 	des_key_schedule ks;
 	int i,err=0;
 
-	key_sched((C_Block *)cfb_key,ks);
+	des_key_sched((C_Block *)cfb_key,ks);
 	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	des_cfb_encrypt(plain,cfb_buf1,bits,(long)sizeof(plain),ks,
 		(C_Block *)cfb_tmp,DES_ENCRYPT);
@@ -691,7 +774,7 @@ unsigned char *cfb_cipher;
 	des_key_schedule ks;
 	int err=0,i,n;
 
-	key_sched((C_Block *)cfb_key,ks);
+	des_key_sched((C_Block *)cfb_key,ks);
 	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	n=0;
 	des_cfb64_encrypt(plain,cfb_buf1,(long)12,ks,
@@ -718,7 +801,45 @@ unsigned char *cfb_cipher;
 		err=1;
 		printf("cfb_encrypt decrypt error\n");
 		for (i=0; i<24; i+=8)
+			printf("%s\n",pt(&(cfb_buf2[i])));
+		}
+	return(err);
+	}
+
+static int ede_cfb64_test(cfb_cipher)
+unsigned char *cfb_cipher;
+	{
+	des_key_schedule ks;
+	int err=0,i,n;
+
+	des_key_sched((C_Block *)cfb_key,ks);
+	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
+	n=0;
+	des_ede3_cfb64_encrypt(plain,cfb_buf1,(long)12,ks,ks,ks,
+		(C_Block *)cfb_tmp,&n,DES_ENCRYPT);
+	des_ede3_cfb64_encrypt(&(plain[12]),&(cfb_buf1[12]),
+		(long)sizeof(plain)-12,ks,ks,ks,
+		(C_Block *)cfb_tmp,&n,DES_ENCRYPT);
+	if (memcmp(cfb_cipher,cfb_buf1,sizeof(plain)) != 0)
+		{
+		err=1;
+		printf("ede_cfb_encrypt encrypt error\n");
+		for (i=0; i<24; i+=8)
 			printf("%s\n",pt(&(cfb_buf1[i])));
+		}
+	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
+	n=0;
+	des_ede3_cfb64_encrypt(cfb_buf1,cfb_buf2,(long)17,ks,ks,ks,
+		(C_Block *)cfb_tmp,&n,DES_DECRYPT);
+	des_ede3_cfb64_encrypt(&(cfb_buf1[17]),&(cfb_buf2[17]),
+		(long)sizeof(plain)-17,ks,ks,ks,
+		(C_Block *)cfb_tmp,&n,DES_DECRYPT);
+	if (memcmp(plain,cfb_buf2,sizeof(plain)) != 0)
+		{
+		err=1;
+		printf("ede_cfb_encrypt decrypt error\n");
+		for (i=0; i<24; i+=8)
+			printf("%s\n",pt(&(cfb_buf2[i])));
 		}
 	return(err);
 	}
