@@ -1,17 +1,22 @@
-/* lib/des/read_pwd.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/des/read_pwd.c */
+/* Copyright (C) 1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -45,43 +56,77 @@
  * [including the GNU Public Licence.]
  */
 
+#ifdef WIN16TTY
+#undef WIN16
+#undef _WINDOWS
+#include <graph.h>
+#endif
+
 /* 06-Apr-92 Luke Brennan    Support for VMS */
 #include "des_locl.h"
-#include <string.h>
 #include <signal.h>
+#include <string.h>
 #include <setjmp.h>
+#include <errno.h>
 
-#ifdef sgi
+/* There are 5 types of terminal interface supported,
+ * TERMIO, TERMIOS, VMS, MSDOS and SGTTY
+ */
+
+#if defined(__sgi) && !defined(TERMIOS)
+#define TERMIOS
+#undef TERMIO
+#undef SGTTY
+#endif
+
+#if defined(linux) && !defined(TERMIO)
+#undef TERMIOS
 #define TERMIO
+#undef SGTTY
 #endif
 
 #ifdef _LIBC
 #define TERMIO
 #endif
 
-#ifndef VMS
-#ifndef MSDOS
+#if !defined(TERMIO) && !defined(TERMIOS) && !defined(VMS) && !defined(MSDOS)
+#define SGTTY
+#endif
+
+#ifdef TERMIOS
+#include <termios.h>
+#define TTY_STRUCT		struct termios
+#define TTY_FLAGS		c_lflag
+#define	TTY_get(tty,data)	tcgetattr(tty,data)
+#define TTY_set(tty,data)	tcsetattr(tty,TCSANOW,data)
+#endif
+
 #ifdef TERMIO
 #include <termio.h>
-#define sgttyb termio
-#define sg_flags c_lflag
-#ifndef TIOCGETP
-#define TIOCGETP TCGETA
+#define TTY_STRUCT		struct termio
+#define TTY_FLAGS		c_lflag
+#define TTY_get(tty,data)	ioctl(tty,TCGETA,data)
+#define TTY_set(tty,data)	ioctl(tty,TCSETA,data)
 #endif
-#ifndef TIOCSETP
-#define TIOCSETP TCSETA
-#endif
-#else /* !TERMIO */
+
+#ifdef SGTTY
 #include <sgtty.h>
+#define TTY_STRUCT		struct sgttyb
+#define TTY_FLAGS		sg_flags
+#define TTY_get(tty,data)	ioctl(tty,TIOCGETP,data)
+#define TTY_set(tty,data)	ioctl(tty,TIOCSETP,data)
 #endif
-#ifndef _LIBC
+
+#if !defined(_LIBC) && !defined(MSDOS) && !defined(VMS)
 #include <sys/ioctl.h>
 #endif
-#else /* MSDOS */
+
+#ifdef MSDOS
 #include <conio.h>
 #define fgets(a,b,c) noecho_fgets(a,b,c)
 #endif
-#else /* VMS */
+
+#ifdef VMS
 #include <ssdef.h>
 #include <iodef.h>
 #include <ttdef.h>
@@ -92,17 +137,18 @@ struct IOSB {
 	long  iosb$l_info;
 	};
 #endif
+
 #ifndef NX509_SIG
 #define NX509_SIG 32
 #endif
 
-#ifdef PROTO
+#ifndef NOPROTO
 static void read_till_nl(FILE *);
 static int read_pw(char *buf, char *buff, int size, char *prompt, int verify);
 static void recsig(int);
 static void pushsig(void);
 static void popsig(void);
-#ifdef MSDOS
+#if defined(MSDOS) && !defined(WIN16)
 static int noecho_fgets(char *buf, int size, FILE *tty);
 #endif
 #else
@@ -111,12 +157,16 @@ static int read_pw();
 static void recsig();
 static void pushsig();
 static void popsig();
-#ifdef MSDOS
+#if defined(MSDOS) && !defined(WIN16)
 static int noecho_fgets();
 #endif
 #endif
 
+#ifndef NOPROTO
+static void (*savsig[NX509_SIG])(int );
+#else
 static void (*savsig[NX509_SIG])();
+#endif
 static jmp_buf save;
 
 int des_read_password(key, prompt, verify)
@@ -164,6 +214,8 @@ int verify;
 	return(ret);
 	}
 
+#ifndef WIN16
+
 static void read_till_nl(in)
 FILE *in;
 	{
@@ -175,6 +227,7 @@ FILE *in;
 		} while (strchr(buf,'\n') == NULL);
 	}
 
+
 /* return 0 if ok, 1 (or -1) otherwise */
 static int read_pw(buf, buff, size, prompt, verify)
 char *buf;
@@ -183,19 +236,22 @@ int size;
 char *prompt;
 int verify;
 	{
-#ifndef VMS
-#ifndef MSDOS
-	struct sgttyb tty_orig,tty_new;
-#endif /* !MSDOS */
-#else
+#ifdef VMS
 	struct IOSB iosb;
 	$DESCRIPTOR(terminal,"TT");
 	long tty_orig[3], tty_new[3];
 	long status;
 	unsigned short channel = 0;
+#else
+#ifndef MSDOS
+	TTY_STRUCT tty_orig,tty_new;
 #endif
+#endif
+	int number=5;
 	int ok=0;
 	int ps=0;
+	int is_a_tty=1;
+
 	FILE *tty=NULL;
 	char *p;
 
@@ -206,13 +262,20 @@ int verify;
 	if ((tty=fopen("con","r")) == NULL)
 		tty=stdin;
 #endif /* MSDOS */
-#ifndef VMS
-#ifdef TIOCGETP
-	if (ioctl(fileno(tty),TIOCGETP,(char *)&tty_orig) == -1)
-		return(-1);
+
+#if defined(TTY_get) && !defined(VMS)
+	if (TTY_get(fileno(tty),&tty_orig) == -1)
+		{
+#ifdef ENOTTY
+		if (errno == ENOTTY)
+			is_a_tty=0;
+		else
+#endif
+			return(-1);
+		}
 	memcpy(&(tty_new),&(tty_orig),sizeof(tty_orig));
 #endif
-#else /* VMS */
+#ifdef VMS
 	status = SYS$ASSIGN(&terminal,&channel,0,0);
 	if (status != SS$_NORMAL)
 		return(-1);
@@ -228,25 +291,26 @@ int verify;
 		}
 	pushsig();
 	ps=1;
-#ifndef VMS
-#ifndef MSDOS
-	tty_new.sg_flags &= ~ECHO;
-#endif /* !MSDOS */
-#ifdef TIOCSETP
-	if (ioctl(fileno(tty),TIOCSETP,(char *)&tty_new) == -1)
+
+#ifdef TTY_FLAGS
+	tty_new.TTY_FLAGS &= ~ECHO;
+#endif
+
+#if defined(TTY_set) && !defined(VMS)
+	if (is_a_tty && (TTY_set(fileno(tty),&tty_new) == -1))
 		return(-1);
 #endif
-#else /* VMS */
+#ifdef VMS
 	tty_new[0] = tty_orig[0];
 	tty_new[1] = tty_orig[1] | TT$M_NOECHO;
 	tty_new[2] = tty_orig[2];
 	status = SYS$QIOW(0,channel,IO$_SETMODE,&iosb,0,0,tty_new,12,0,0,0,0);
 	if ((status != SS$_NORMAL) || (iosb.iosb$w_value != SS$_NORMAL))
 		return(-1);
-#endif /* VMS */
+#endif
 	ps=2;
 
-	while (!ok)
+	while ((!ok) && (number--))
 		{
 		fputs(prompt,stderr);
 		fflush(stderr);
@@ -254,12 +318,13 @@ int verify;
 		buf[0]='\0';
 		fgets(buf,size,tty);
 		if (feof(tty)) goto error;
+		if (ferror(tty)) goto error;
 		if ((p=(char *)strchr(buf,'\n')) != NULL)
 			*p='\0';
 		else	read_till_nl(tty);
 		if (verify)
 			{
-			fprintf(stderr,"\nVerifying password %s",prompt);
+			fprintf(stderr,"\nVerifying password - %s",prompt);
 			fflush(stderr);
 			buff[0]='\0';
 			fgets(buff,size,tty);
@@ -270,9 +335,10 @@ int verify;
 				
 			if (strcmp(buf,buff) != 0)
 				{
-				fprintf(stderr,"\nVerify failure - try again\n");
+				fprintf(stderr,"\nVerify failure");
 				fflush(stderr);
-				continue;
+				break;
+				/* continue; */
 				}
 			}
 		ok=1;
@@ -280,16 +346,18 @@ int verify;
 
 error:
 	fprintf(stderr,"\n");
-	/* What can we do if there is an error? */
-#ifndef VMS
-#ifdef TIOCSETP
-	if (ps >= 2) ioctl(fileno(tty),TIOCSETP,(char *)&tty_orig);
+#ifdef DEBUG
+	perror("fgets(tty)");
 #endif
-#else /* VMS */
+	/* What can we do if there is an error? */
+#if defined(TTY_set) && !defined(VMS) 
+	if (ps >= 2) TTY_set(fileno(tty),&tty_orig);
+#endif
+#ifdef VMS
 	if (ps >= 2)
 		status = SYS$QIOW(0,channel,IO$_SETMODE,&iosb,0,0
 			,tty_orig,12,0,0,0,0);
-#endif /* VMS */
+#endif
 	
 	if (ps >= 1) popsig();
 	if (stdin != tty) fclose(tty);
@@ -299,12 +367,32 @@ error:
 	return(!ok);
 	}
 
+#else /* WIN16 */
+
+static int read_pw(buf, buff, size, prompt, verify)
+char *buf;
+char *buff;
+int size;
+char *prompt;
+int verify;
+	{ 
+	memset(buf,0,size);
+	memset(buff,0,size);
+	return(0);
+	}
+
+#endif
+
 static void pushsig()
 	{
 	int i;
 
 	for (i=1; i<NX509_SIG; i++)
 		savsig[i]=signal(i,recsig);
+
+#ifdef SIGWINCH
+	signal(SIGWINCH,SIG_DFL);
+#endif
 	}
 
 static void popsig()
@@ -324,13 +412,13 @@ int i;
 #endif
 	}
 
-#ifdef MSDOS
+#if defined(MSDOS) && !defined(WIN16)
 static int noecho_fgets(buf,size,tty)
 char *buf;
 int size;
 FILE *tty;
 	{
-	int i,n;
+	int i;
 	char *p;
 
 	p=buf;
@@ -342,7 +430,11 @@ FILE *tty;
 			break;
 			}
 		size--;
+#ifdef WIN16TTY
+		i=_inchar();
+#else
 		i=getch();
+#endif
 		if (i == '\r') i='\n';
 		*(p++)=i;
 		if (i == '\n')
